package com.jiuqi.mde;

import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.net.URLEncoder;
import java.util.Arrays;
import java.util.StringTokenizer;

/* loaded from: com_jiuqi_mde.jar:com/jiuqi/mde/MDEDimValueSet.class */
public final class MDEDimValueSet implements Cloneable, Comparable {
    private MDEDimensionSet dimensions;
    private Object[] dimValues;

    public MDEDimValueSet(MDEDimensionSet dimensions) {
        this.dimensions = dimensions;
        this.dimValues = new Object[dimensions.size()];
    }

    public int size() {
        return this.dimensions.size();
    }

    public MDEDimensionSet dimensions() {
        return this.dimensions;
    }

    public MDEDimension getDimension(int index) {
        return this.dimensions.get(index);
    }

    public Object getValue(int index) {
        return this.dimValues[index];
    }

    public Object getValue(MDEDimension dimension) {
        int index = this.dimensions.indexOf(dimension);
        if (index >= 0) {
            return this.dimValues[index];
        }
        return null;
    }

    public Object getValue(String dimName) {
        int index = this.dimensions.indexOf(dimName);
        if (index >= 0) {
            return this.dimValues[index];
        }
        return null;
    }

    public void setValue(int index, Object value) {
        if (value == null) {
            this.dimValues[index] = null;
            return;
        }
        if (this.dimensions.get(index).isString) {
            this.dimValues[index] = value.toString();
        } else if (value instanceof Double) {
            this.dimValues[index] = new Integer(((Double) value).intValue());
        } else {
            this.dimValues[index] = value;
        }
    }

    public void setValue(MDEDimension dimension, Object value) {
        int index = this.dimensions.indexOf(dimension);
        if (index >= 0) {
            setValue(index, value);
        }
    }

    public void setValue(String dimName, Object value) {
        int index = this.dimensions.indexOf(dimName);
        if (index >= 0) {
            setValue(index, value);
        }
    }

    public Object[] getDimValues() {
        return this.dimValues;
    }

    public void setDimValues(Object[] dimValues) {
        this.dimValues = dimValues;
    }

    public void assignValues(MDEDimValueSet source) {
        if (source == null) {
            return;
        }
        if (this.dimensions == source.dimensions) {
            int count = source.size();
            for (int i = 0; i < count; i++) {
                this.dimValues[i] = source.dimValues[i];
            }
            return;
        }
        int count2 = source.size();
        for (int i2 = 0; i2 < count2; i2++) {
            setValue(source.dimensions.get(i2), source.dimValues[i2]);
        }
    }

    public void assignValues(MDEDimValueSet source, boolean assignNull) {
        if (source == null) {
            return;
        }
        if (this.dimensions == source.dimensions) {
            int count = source.size();
            for (int i = 0; i < count; i++) {
                Object value = source.dimValues[i];
                if (assignNull || value != null) {
                    setValue(i, value);
                }
            }
            return;
        }
        int count2 = source.size();
        for (int i2 = 0; i2 < count2; i2++) {
            Object value2 = source.dimValues[i2];
            if (assignNull || value2 != null) {
                setValue(source.dimensions.get(i2), value2);
            }
        }
    }

    public void assignNullValues(MDEDimValueSet source) {
        if (source == null) {
            return;
        }
        int count = this.dimensions.size();
        for (int i = 0; i < count; i++) {
            Object value = this.dimValues[i];
            if (value == null) {
                setValue(i, source.getValue(this.dimensions.get(i)));
            }
        }
    }

    public void clear() {
        Arrays.fill(this.dimValues, (Object) null);
    }

    public Object clone() {
        MDEDimValueSet result = new MDEDimValueSet(this.dimensions);
        int count = this.dimensions.size();
        for (int i = 0; i < count; i++) {
            result.setValue(i, this.dimValues[i]);
        }
        return result;
    }

    @Override // java.lang.Comparable
    public int compareTo(Object o) {
        if (this == o) {
            return 0;
        }
        if (o == null) {
            return 1;
        }
        if (this == null) {
            return -1;
        }
        if (o instanceof MDEDimValueSet) {
            int result = this.dimensions.compareTo(((MDEDimValueSet) o).dimensions);
            if (result != 0) {
                return result;
            }
            int count = this.dimensions.size();
            for (int i = 0; i < count; i++) {
                Object o1 = this.dimValues[i];
                Object o2 = ((MDEDimValueSet) o).dimValues[i];
                if (o1 != o2) {
                    if (o1 == null) {
                        return -1;
                    }
                    if (o2 == null) {
                        return 1;
                    }
                    if (o1 instanceof Comparable) {
                        result = ((Comparable) o1).compareTo(o2);
                    } else {
                        result = o1.hashCode() - o2.hashCode();
                    }
                    if (result != 0) {
                        return result;
                    }
                }
            }
            return result;
        }
        return hashCode() - o.hashCode();
    }

    public int compareNoOrder(Object o) {
        Object o1;
        Object o2;
        if (this == o) {
            return 0;
        }
        if (!(o instanceof MDEDimValueSet)) {
            return -1;
        }
        int result = this.dimensions.compareTo(((MDEDimValueSet) o).dimensions);
        if (result != 0) {
            return result;
        }
        int count = this.dimensions.size();
        for (int i = 0; i < count; i++) {
            if (!this.dimensions.get(i).name.equals(MDEDimension.ORDER_NAME) && (o1 = this.dimValues[i]) != (o2 = ((MDEDimValueSet) o).dimValues[i])) {
                if (o1 == null) {
                    return -1;
                }
                if (o2 == null) {
                    return 1;
                }
                if (o1 instanceof Comparable) {
                    result = ((Comparable) o1).compareTo(o2);
                } else {
                    result = o1.hashCode() - o2.hashCode();
                }
                if (result != 0) {
                    return result;
                }
            }
        }
        return result;
    }

    public boolean equals(Object o) {
        if (!(o instanceof MDEDimValueSet) || this.dimensions.compareTo(((MDEDimValueSet) o).dimensions) != 0) {
            return false;
        }
        int count = this.dimensions.size();
        for (int i = 0; i < count; i++) {
            Object o1 = this.dimValues[i];
            Object o2 = ((MDEDimValueSet) o).dimValues[i];
            if (o1 != o2 && (o1 == null || o2 == null || !o1.equals(o2))) {
                return false;
            }
        }
        return true;
    }

    public boolean matches(MDEDimValueSet speciafication) {
        if (speciafication == null) {
            return true;
        }
        int count = speciafication.dimensions.size();
        for (int i = 0; i < count; i++) {
            Object spec = speciafication.getValue(i);
            if (spec != null) {
                MDEDimension dimension = speciafication.dimensions.get(i);
                int index = this.dimensions.indexOf(dimension);
                if (index < 0) {
                    continue;
                } else {
                    Object value = getValue(index);
                    if (!spec.equals(value)) {
                        return false;
                    }
                }
            }
        }
        return true;
    }

    protected boolean isNullValue(Object value) {
        return value == null || "".equals(value);
    }

    public boolean isEmpty() {
        for (int i = 0; i < this.dimValues.length; i++) {
            if (!isNullValue(this.dimValues[i])) {
                return false;
            }
        }
        return true;
    }

    public boolean hasNullValue() {
        return hasNullValue(false);
    }

    public boolean hasNullValue(boolean includeOrder) {
        for (int i = 0; i < this.dimValues.length; i++) {
            if (isNullValue(this.dimValues[i]) && (includeOrder || !MDEDimension.ORDER_NAME.equals(this.dimensions.get(i).name))) {
                return true;
            }
        }
        return false;
    }

    public String encodeData() {
        String result = "";
        for (int i = 0; i < this.dimensions.size(); i++) {
            Object value = this.dimValues[i];
            String data = "";
            if (value != null) {
                if (this.dimensions.get(i).isString) {
                    data = (String) value;
                } else {
                    int numVal = value instanceof Integer ? ((Integer) value).intValue() : ((Double) value).intValue();
                    data = Integer.toString(numVal);
                }
            }
            if (i > 0) {
                result = String.valueOf(result) + "&";
            }
            try {
                result = String.valueOf(result) + URLEncoder.encode(data, "GBK");
            } catch (UnsupportedEncodingException e) {
                throw new RuntimeException("系统没有配置GBK字符集！", e);
            }
        }
        return result;
    }

    public void decodeData(String encodedData) throws MDEException {
        if (encodedData == null) {
            return;
        }
        try {
            int index = 0;
            StringTokenizer st = new StringTokenizer(encodedData, "&");
            while (st.hasMoreTokens()) {
                try {
                    String data = URLDecoder.decode(st.nextToken(), "GBK");
                    if (this.dimensions.get(index).isString) {
                        this.dimValues[index] = data;
                    } else {
                        this.dimValues[index] = Integer.valueOf(data);
                    }
                    index++;
                } catch (UnsupportedEncodingException e) {
                    throw new RuntimeException("系统没有配置GBK字符集！", e);
                }
            }
        } catch (NumberFormatException ex) {
            throw new MDEException(ex);
        }
    }

    public void parseString(String strData) throws MDEException {
        MDEDimension dim;
        try {
            StringTokenizer st = new StringTokenizer(strData, ";,");
            while (st.hasMoreTokens()) {
                String data = st.nextToken();
                int p = data.indexOf(61);
                if (p > 0 && (dim = this.dimensions.find(data.substring(0, p).trim())) != null) {
                    int index = this.dimensions.indexOf(dim);
                    String data2 = data.substring(p + 1);
                    if (dim.isString) {
                        if (data2.length() > 2 && data2.charAt(0) == '\"' && data2.charAt(data2.length() - 1) == '\"') {
                            data2 = data2.substring(1, data2.length() - 2);
                        }
                        this.dimValues[index] = data2;
                    } else {
                        this.dimValues[index] = Integer.valueOf(data2);
                    }
                    int i = index + 1;
                }
            }
        } catch (NumberFormatException ex) {
            throw new MDEException(ex);
        }
    }

    public String toString() {
        StringBuffer result = new StringBuffer(64);
        boolean needComma = false;
        int count = this.dimensions.size();
        for (int i = 0; i < count; i++) {
            if (this.dimValues[i] != null) {
                MDEDimension dimension = this.dimensions.get(i);
                if (needComma) {
                    result.append(", ");
                }
                result.append(dimension.name);
                result.append('=');
                if (dimension.isString) {
                    result.append('\"');
                    result.append((String) this.dimValues[i]);
                    result.append('\"');
                } else if (this.dimValues[i] instanceof Integer) {
                    result.append(((Integer) this.dimValues[i]).intValue());
                } else {
                    result.append(this.dimValues[i].toString());
                }
                needComma = true;
            }
        }
        return result.toString();
    }

    public String getSQLFilter() {
        return getSQLFilter(false);
    }

    public String getSQLFilter(boolean isPrepared) {
        return getSQLFilter(null, isPrepared);
    }

    public String getSQLFilter(String tablePrefix) {
        return getSQLFilter(tablePrefix, false);
    }

    public String getSQLFilter(String tablePrefix, boolean isPrepared) {
        StringBuffer filter = new StringBuffer(128);
        boolean needAND = false;
        int count = this.dimensions.size();
        for (int i = 0; i < count; i++) {
            if (this.dimValues[i] != null) {
                MDEDimension dimension = this.dimensions.get(i);
                if (needAND) {
                    filter.append(" AND ");
                }
                filter.append(dimension.getSQLFilter(tablePrefix, this.dimValues[i], isPrepared));
                needAND = true;
            }
        }
        return filter.toString();
    }
}
